@@ -1,3 +1,4 @@
+# $Id: Exception.pm 495 2005-05-30 01:38:24Z claco $
 package Handel::Exception;
 use strict;
 use warnings;
@@ -58,6 +59,48 @@ sub new {
         -text => 'The argument supplied is invalid or of the wrong type', @_ );
 };
 
+package Handel::Exception::Taglib;
+use strict;
+use warnings;
+
+BEGIN {
+    use base 'Handel::Exception';
+};
+
+sub new {
+    my $class = shift;
+    return $class->SUPER::new(
+        -text => 'The tag is out of scope or missing required child tags', @_ );
+};
+
+package Handel::Exception::Order;
+use strict;
+use warnings;
+
+BEGIN {
+    use base 'Handel::Exception';
+};
+
+sub new {
+    my $class = shift;
+    return $class->SUPER::new(
+        -text => 'An error occurred while while creating or validating the current order', @_ );
+};
+
+package Handel::Exception::Checkout;
+use strict;
+use warnings;
+
+BEGIN {
+    use base 'Handel::Exception';
+};
+
+sub new {
+    my $class = shift;
+    return $class->SUPER::new(
+        -text => 'An error occurred during the checkout process', @_ );
+};
+
 1;
 __END__
 
@@ -65,10 +108,6 @@ __END__
 
 Handel::Exception - Exceptions used within Handel
 
-=head1 VERSION
-
-    $Id: Exception.pm 53 2004-12-31 23:13:51Z claco $
-
 =head1 SYNOPSIS
 
     use Handel::Cart;
@@ -95,10 +134,10 @@ unexpected things happen.
 
 =head1 EXCEPTIONS
 
-=head2 C<Handel::Exception>
+=head2 Handel::Exception
 
 This is the base exception thrown in C<Handel>. All other exceptions subclass
-C<Handel::Exception> so it's possibly to catch all Handel generated exceptions
+C<Handel::Exception> so it's possibl to catch all Handel generated exceptions
 with a single C<catch> statement.
 
     try {
@@ -107,7 +146,7 @@ with a single C<catch> statement.
         my $E = shift;
         print 'Something bad happened in Handel: ' . E->text;
 
-    } catch MyApplicaitonException with {
+    } catch MyApplicationException with {
         print 'Something bad happened in MyApplication';
 
     };
@@ -115,30 +154,43 @@ with a single C<catch> statement.
 See L<Error> for more information on how to use
 exceptions.
 
-=head2 C<Handel::Exception::Constraint>
+=head2 Handel::Exception::Constraint
 
 This exception is thrown if a database constraint is violated. This is true for
 both raw DBI database constraint errors as well as  field updates that don't
 pass constraints in C<Handel::Constraints>.
 
-=head2 C<Handel::Exception::Argument>
+=head2 Handel::Exception::Argument
 
 This exception is thrown when an invalid or unexpected argument value is passed
 into methods.
 
+=head2 Handel::Exception::Taglib
+
+This exception is thrown when an unexpected error occurs within
+C<AxKit::XSP::Handel::Cart> taglib.
+
+=head1 METHODS
+
+=head2 new
+
+This returns a new C<Handel::Exception> object. This is mostly used internally
+by L<Error>. In most circumstance, you don't need to call C<new> at all.
+Instead, simply use the C<throw> syntax:
+
+    use Handel::Exceptions;
+
+    throw Handel::Exception::Taglib(
+        -text => translate("Tag '[_1]' not valid inside of other Handel tags", $tag)
+    ) if ($context[$#context] ne 'root');
+
 =head1 SEE ALSO
 
-L<Error>, L<Handel::constraints>
+L<Error>, L<Handel::Constraints>
 
 =head1 AUTHOR
 
     Christopher H. Laco
     CPAN ID: CLACO
-    cpan@chrislaco.com
+    claco@chrislaco.com
     http://today.icantfocus.com/blog/
-
-
-
-
-
-
