@@ -1,4 +1,4 @@
-# $Id: Item.pm 502 2005-06-06 00:07:51Z claco $
+# $Id: Item.pm 588 2005-07-15 02:10:14Z claco $
 package Handel::Order::Item;
 use strict;
 use warnings;
@@ -13,14 +13,14 @@ BEGIN {
 __PACKAGE__->table('order_items');
 __PACKAGE__->autoupdate(0);
 __PACKAGE__->iterator_class('Handel::Iterator');
-__PACKAGE__->columns(All => qw(id order sku quantity price description total));
-__PACKAGE__->columns(Essential => qw(id order sku quantity price description total));
+__PACKAGE__->columns(All => qw(id orderid sku quantity price description total));
+__PACKAGE__->columns(Essential => qw(id orderid sku quantity price description total));
 __PACKAGE__->has_a(price => 'Handel::Currency');
 __PACKAGE__->has_a(total => 'Handel::Currency');
 __PACKAGE__->add_constraint('quantity', quantity => \&constraint_quantity);
 __PACKAGE__->add_constraint('price',    price    => \&constraint_price);
 __PACKAGE__->add_constraint('id',       id       => \&constraint_uuid);
-__PACKAGE__->add_constraint('order',    order    => \&constraint_uuid);
+__PACKAGE__->add_constraint('orderid',  orderid  => \&constraint_uuid);
 __PACKAGE__->add_constraint('total',    total    => \&constraint_price);
 
 
@@ -44,6 +44,32 @@ Handel::Order::Item - Module representing an indivudal order line item
         print $item->total;
     };
 
+=head1 METHOS
+
+=head2 description
+
+Gets/sets the item description
+
+=head2 id
+
+Gets/sets the item id
+
+=head2 price
+
+Gets/sets the item price
+
+=head2 quantity
+
+Gets/sets the item quantity
+
+=head2 sku
+
+Gets/sets the item sku
+
+=head2 total
+
+Gets/sets the item total
+
 =head1 AUTHOR
 
     Christopher H. Laco
